# AntU
Universal data IO and neural network modules in NLP tasks.

+ **data IO** is an universal module in Natural Language Processing system and not based on any framework (like TensorFlow, PyTorch, MXNet, Dynet...).
+ **neural network** module contains the neural network structures commonly used in NLP tasks. We want to design commonly used structures for each neural network framework. We will continue to develop this module.



# Requirements

+ Python>=3.6
+ bidict
+ overrides

##### If you need dynet neural network:

+ dynet>=2.0



# Resources

+ [Documentation](https://wait)
+ [Source Code](https://github.com/AntNLP/antu)

